summaryrefslogtreecommitdiffstats
path: root/macosx/tkMacOSXPort.h
diff options
context:
space:
mode:
Diffstat (limited to 'macosx/tkMacOSXPort.h')
-rw-r--r--macosx/tkMacOSXPort.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/macosx/tkMacOSXPort.h b/macosx/tkMacOSXPort.h
index 461204e..abf02d0 100644
--- a/macosx/tkMacOSXPort.h
+++ b/macosx/tkMacOSXPort.h
@@ -163,11 +163,16 @@
#define TK_DYNAMIC_COLORMAP 0x0fffffff
/*
* Inform tkImgPhInstance.c that our tkPutImage can render an image with an
* alpha channel directly into a window.
*/
-#define TKPUTIMAGE_CAN_BLEND
+#define TK_CAN_RENDER_RGBA
+
+MODULE_SCOPE int TkpPutRGBAImage(unsigned long *colors, int ncolors,
+ Display* display, Drawable drawable, GC gc,XImage* image,
+ int src_x, int src_y, int dest_x, int dest_y,
+ unsigned int width, unsigned int height);
/*
* Used by xcolor.c
@@ -163,11 +163,16 @@
#define TK_DYNAMIC_COLORMAP 0x0fffffff
/*
- * Inform tkImgPhInstance.c that our tkPutImage can render an image with an
- * alpha channel directly into a window.
+ * Inform tkImgPhInstance.c that we implement TkpPutRGBAImage to render RGBA
+ * images directly into a window.
*/